@@ -17,6 +17,9 @@ class TeacherErrorCode(AbstractErrorCode):
     }
 
     def _init_(self, error):
+        self._set_error(error)
+
+    def _set_error(self, error):
         self._errorCode = ''
         self._errorDesc = None
         for k, v in error.items():
