@@ -18,7 +18,8 @@ class CourseConstant:
     MATERIAL_Id = 'materialId'
     PATH = 'path'
 
-    COURSE_PACKAGE_HORIZONTAL_COVER = 'COURSE_PACKAGE_HORIZONTAL_COVER'
+    COURSE_LESSON_PACKAGE_HORIZONTAL_COVER = \
+        'COURSE_LESSON_PACKAGE_HORIZONTAL_COVER'
     COURSE_PORTRAIT_COVER = 'COURSE_PORTRAIT_COVER'
     COURSE_PACKAGE_INTRODUCTION = 'COURSE_PACKAGE_INTRODUCTION'
     PROMOTIONAL_VIDEO_POSTER = 'PROMOTIONAL_VIDEO_POSTER'
