@@ -58,14 +58,14 @@ class CourseHandler:
                 response.get_rsp(), CourseConstant.CREATE_COURSE_RESULT)
         except EduKitException as e:
             logging.error(
-                'Call course createCourse interface failed.error_message: %s' %
+                'Call course createCourse interface failed.error_message: %s',
                 e.message)
             create_course_result.result = Helpers.build_error_result(
                 CommonErrorCode.CALL_API_INTERFACE_FAILED)
         logging.info(
             'Call course createCourse interface end,and course_id: '
             '%s, edit_id: %s'
-            % (create_course_result.course_id, create_course_result.edit_id))
+            , create_course_result.course_id, create_course_result.edit_id)
 
         return create_course_result
 
@@ -130,7 +130,7 @@ class CourseHandler:
         logging.info(
             'Call course updateMetaData interface start and '
             'course_id:%s, edit_id:%s'
-            % (create_course_result.course_id, create_course_result.edit_id))
+            , create_course_result.course_id, create_course_result.edit_id)
         try:
             url = ApiConstant.UPDATE_META_COURSE_URL.format(
                 create_course_result.course_id, create_course_result.edit_id)
@@ -141,8 +141,8 @@ class CourseHandler:
             logging.error(
                 'Call course updateMetaData interface failed and '
                 'course_id:%s, edit_id:%s, error_message:%s'
-                % (create_course_result.course_id,
-                   create_course_result.edit_id, e.message))
+                , create_course_result.course_id,
+                   create_course_result.edit_id, e.message)
             return False
 
         if not Helpers.is_success(update_meta_data_response.get_rsp()):
@@ -150,12 +150,12 @@ class CourseHandler:
             logging.error(
                 'Call course updateMetaData interface failed and '
                 'course_id:%s,edit_id:%s,error_message:%s,resultCode:'
-                '%s' %
-                (create_course_result.course_id, create_course_result.edit_id,
+                '%s',
+                create_course_result.course_id, create_course_result.edit_id,
                  result.get(CourseConstant.RESULT).get(
                      CourseConstant.RESULT_DESC),
                  result.get(CourseConstant.RESULT).get(
-                     CourseConstant.RESULT_CODE)))
+                     CourseConstant.RESULT_CODE))
             return False
 
         logging.info('Call course updateMetaData interface end')
@@ -169,8 +169,8 @@ class CourseHandler:
         logging.info(
             'Call course updateLocalizedData interface start when updating '
             'course localizedData and course_id:%s, edit_'
-            'id:%s' %
-            (create_course_result.course_id, create_course_result.edit_id))
+            'id:%s',
+            create_course_result.course_id, create_course_result.edit_id)
         update_flag = True
         for course_multi_language_data in \
                 course.course_multi_language_data_list:
@@ -215,28 +215,28 @@ class CourseHandler:
                     logging.error(
                         'Call course updateLocalizedData interface failed '
                         'and course_id:%s, edit_id:%s, error_message:'
-                        ' %s, resultCode: %s' %
-                        (create_course_result.course_id,
+                        ' %s, resultCode: %s',
+                         create_course_result.course_id,
                          create_course_result.edit_id,
                          result.get(CourseConstant.RESULT).get(
                              CourseConstant.RESULT_DESC),
                          result.get(CourseConstant.RESULT).get(
-                             CourseConstant.RESULT_CODE)))
+                             CourseConstant.RESULT_CODE))
                     update_flag = False
                     break
             except EduKitException as e:
                 logging.error(
                     'Call course updateLocalizedData interface failed and '
                     'course_id:%s, edit_id:%s, error_message: %s'
-                    % (create_course_result.course_id,
-                       create_course_result.edit_id, e.message))
+                    , create_course_result.course_id,
+                       create_course_result.edit_id, e.message)
                 update_flag = False
                 break
 
         logging.info(
             'Call course updateLocalizedData interface end and '
             'course_id:%s, edit_id:%s'
-            % (create_course_result.course_id, create_course_result.edit_id))
+            , create_course_result.course_id, create_course_result.edit_id)
         return update_flag
 
     def _del_course_localized_data(self, course: Course,
@@ -246,8 +246,8 @@ class CourseHandler:
             logging.info(
                 'Call course deleteLocalizedData interface start and '
                 'course_id:%s,edit_id:%s,language:%s'
-                % (create_course_result.course_id,
-                   create_course_result.edit_id, language))
+                , create_course_result.course_id,
+                   create_course_result.edit_id, language)
             try:
                 url = ApiConstant.DELETE_COURSE_URL.format(
                     create_course_result.course_id,
@@ -259,30 +259,30 @@ class CourseHandler:
                     logging.error(
                         'Call course deleteLocalizedData interface failed and '
                         'course_id:%s, edit_id:%s, language:%s, '
-                        'errormessage: %s, errorCode: %s' %
-                        (create_course_result.course_id,
+                        'errormessage: %s, errorCode: %s',
+                        create_course_result.course_id,
                          create_course_result.edit_id, language,
                          result.get(CourseConstant.RESULT).get(
                              CourseConstant.RESULT_DESC),
                          result.get(CourseConstant.RESULT).get(
-                             CourseConstant.RESULT_CODE)))
+                             CourseConstant.RESULT_CODE))
                     del_flag = False
                     break
             except EduKitException as e:
                 logging.error(
                     'Call course deleteLocalizedData interface failed and '
                     'course_id:%s, edit_id:%s, language:%s, error'
-                    'message:%s, errorCode:%s' %
-                    (create_course_result.course_id,
+                    'message:%s, errorCode:%s',
+                    create_course_result.course_id,
                      create_course_result.edit_id, language, e.message,
-                     e.code))
+                     e.code)
                 del_flag = False
                 break
             logging.info(
                 'Call course deleteLocalizedData interface end and '
                 'course_id:%s,edit_id:%s,language:%s'
-                % (create_course_result.course_id,
-                   create_course_result.edit_id, language))
+                , create_course_result.course_id,
+                   create_course_result.edit_id, language)
 
         return del_flag
 
@@ -291,8 +291,6 @@ class CourseHandler:
             return
         if not course.course_meta_data.meta_data:
             return
-        if not course.course_meta_data.meta_data.include_lessons:
-            return
 
         multi_language_data_list = course.course_multi_language_data_list
         for multi_language_data in multi_language_data_list:
@@ -355,7 +353,7 @@ class CourseHandler:
             return Helpers.build_error_result(
                 CommonErrorCode.INVALID_COURSE_PARAMS)
         course_id = course.course_id
-        logging.info('OffShelf course start and course_id: %s' % course_id)
+        logging.info('OffShelf course start and course_id: %s', course_id)
         response = Response()
         try:
             url = ApiConstant.REMOVE_COURSE_URL.format(course_id)
@@ -368,7 +366,7 @@ class CourseHandler:
             logging.error(
                 'Call offShelf course interface failed and '
                 'course_id:%s,error_message:%s'
-                % (course_id, e.message))
+                , course_id, e.message)
             response.result = Helpers.build_error_result(
                 CommonErrorCode.CALL_API_INTERFACE_FAILED)
             return response
@@ -377,14 +375,14 @@ class CourseHandler:
             logging.error(
                 'Call offShelf course interface failed.course_id:%s,'
                 'error_message:%s'
-                % (course_id, result.get(CourseConstant.RESULT).get(
-                    CourseConstant.RESULT_DESC)))
+                , course_id, result.get(CourseConstant.RESULT).get(
+                    CourseConstant.RESULT_DESC))
             response.result = Helpers.build_error_result(
                 CommonErrorCode.CALL_API_INTERFACE_FAILED)
             return response
 
         logging.info(
-            'OffShelf course end and result: %s' %
+            'OffShelf course end and result: %s',
             Helpers.build_result(http_common_response.get_rsp()).to_string())
         response.result = Helpers.build_result(http_common_response.get_rsp())
         return response
@@ -395,7 +393,7 @@ class CourseHandler:
             return Helpers.build_error_result(
                 CommonErrorCode.INVALID_COURSE_PARAMS)
         logging.info(
-            'Call course getCourseStatus interface start,and course_id: %s' %
+            'Call course getCourseStatus interface start,and course_id: %s',
             course_id)
         course_status_response = CourseStatusResponse()
         try:
@@ -407,10 +405,10 @@ class CourseHandler:
                 result = response.get_rsp()
                 logging.error(
                     'Call course getCourseStatus interface failed.'
-                    'course_id:%s,error_message:%s' %
-                    (course_id, result.get(
+                    'course_id:%s,error_message:%s',
+                    course_id, result.get(
                         CourseConstant.RESULT).get(
-                        CourseConstant.RESULT_DESC)))
+                        CourseConstant.RESULT_DESC))
                 course_status_response.result = Helpers.build_error_result(
                     CommonErrorCode.CALL_API_INTERFACE_FAILED)
                 return course_status_response
@@ -419,8 +417,7 @@ class CourseHandler:
         except EduKitException as e:
             logging.error(
                 'Call course getCourseStatus interface failed and '
-                'course_id:%s, errorMsg:%s.'
-                % (course_id, e.message))
+                'course_id:%s, errorMsg:%s.', course_id, e.message)
             course_status_response.result = Helpers.build_error_result(
                 CommonErrorCode.CALL_API_INTERFACE_FAILED)
             return course_status_response
@@ -470,12 +467,12 @@ class CourseHandler:
                 request_sender=self._request_sender)
             result = file_upload.upload()
         except EduKitException as e:
-            logging.error('Upload horizon cover image failed. errMsg:%s' %
+            logging.error('Upload horizon cover image failed. errMsg:%s',
                           e.message)
             return False
 
         if not Helpers.is_success(result):
-            logging.error('Upload horizon cover image failed. errMsg:%s' %
+            logging.error('Upload horizon cover image failed. errMsg:%s',
                           result.get(CourseConstant.RESULT).get(
                               CourseConstant.RESULT_DESC))
             return False
@@ -495,12 +492,11 @@ class CourseHandler:
                 request_sender=self._request_sender)
             result = file_upload.upload()
         except EduKitException as e:
-            logging.error('Upload portrait image failed. errMsg:%s' %
-                          e.message)
+            logging.error('Upload portrait image failed. errMsg:%s', e.message)
             return False
 
         if not Helpers.is_success(result):
-            logging.error('Upload portrait image failed. errMsg:%s' %
+            logging.error('Upload portrait image failed. errMsg:%s',
                           result.get(CourseConstant.RESULT).get(
                               CourseConstant.RESULT_DESC))
             return False
@@ -526,7 +522,7 @@ class CourseHandler:
                 return False
 
             if not Helpers.is_success(result):
-                logging.error('Upload introduce image failed. errMsg:%s' %
+                logging.error('Upload introduce image failed. errMsg:%s',
                               result.get(CourseConstant.RESULT).get(
                                   CourseConstant.RESULT_DESC))
                 return False
@@ -547,11 +543,11 @@ class CourseHandler:
                 request_sender=self._request_sender)
             result = file_upload.upload()
         except EduKitException as e:
-            logging.error('Upload frame image failed. errMsg: %s' % e.message)
+            logging.error('Upload frame image failed. errMsg: %s', e.message)
             return False
 
         if not Helpers.is_success(result):
-            logging.error('Upload frame image failed. errMsg: %s' % result.get(
+            logging.error('Upload frame image failed. errMsg: %s', result.get(
                 CourseConstant.RESULT).get(CourseConstant.RESULT_DESC))
             return False
 
@@ -573,11 +569,11 @@ class CourseHandler:
                 request_sender=self._request_sender)
             result = file_upload.upload()
         except EduKitException as e:
-            logging.error('Upload media failed. errMsg: %s' % e.message)
+            logging.error('Upload media failed. errMsg: %s', e.message)
             return False
 
         if not Helpers.is_success(result):
-            logging.error('Upload media failed. errMsg: %s' % result.get(
+            logging.error('Upload media failed. errMsg: %s', result.get(
                 CourseConstant.RESULT).get(CourseConstant.RESULT_DESC))
             return False
 
@@ -588,7 +584,7 @@ class CourseHandler:
 
     def _update_product_price(self, produce_prices, course_id):
         logging.info(
-            'Call course updateProductPrice interface start and course_id:%s' %
+            'Call course updateProductPrice interface start and course_id:%s',
             course_id)
         try:
             update_product_price_request = UpdateProductPriceRequest()
@@ -601,7 +597,7 @@ class CourseHandler:
             logging.error(
                 'Call course updateProductPrice interface failed and '
                 'course_id:%s, error_message:%s'
-                % (course_id, e.message))
+                , course_id, e.message)
             return False
 
         if not Helpers.is_success(response.get_rsp()):
@@ -609,10 +605,10 @@ class CourseHandler:
             logging.error(
                 'Call course updateProductPrice interface failed and '
                 'course_id:%s, error_message:%s, resultCode:%s'
-                % (course_id, result.get(CourseConstant.RESULT).get(
+                , course_id, result.get(CourseConstant.RESULT).get(
                     CourseConstant.RESULT_DESC),
                    result.get(CourseConstant.RESULT).get(
-                       CourseConstant.RESULT_CODE)))
+                       CourseConstant.RESULT_CODE))
             return False
 
         logging.info('Call course updateProductPrice interface end')
@@ -622,8 +618,7 @@ class CourseHandler:
                       change_course_status_request: ChangeCourseStatusRequest):
         logging.info(
             'Call course commit_course interface start and course_id:%s, '
-            'edit_id:%s'
-            % (course_id, edit_id))
+            'edit_id:%s', course_id, edit_id)
         try:
             if course.change_course_status_data and \
                     course.change_course_status_data.remarks:
@@ -641,7 +636,7 @@ class CourseHandler:
             logging.error(
                 'Call course commit_course interface failed and course_id:%s, '
                 'edit_id:%s, error_message: %s'
-                % (course_id, edit_id, e.message))
+                , course_id, edit_id, e.message)
 
             return Helpers.build_error_result(
                 CommonErrorCode.CALL_API_INTERFACE_FAILED)
@@ -652,10 +647,10 @@ class CourseHandler:
                 'Call course commit_course interface failed and course_id:%s, '
                 'edit_id:%s, error_message: %s, result_'
                 'code'
-                ': %s' % (course_id, edit_id, result.get(
+                ': %s', course_id, edit_id, result.get(
                     CourseConstant.RESULT).get(CourseConstant.RESULT_DESC),
                     result.get(CourseConstant.RESULT).get(
-                    CourseConstant.RESULT_CODE)))
+                    CourseConstant.RESULT_CODE))
 
             return Helpers.build_error_result(
                 CommonErrorCode.CALL_API_INTERFACE_FAILED)
@@ -676,7 +671,7 @@ class CourseHandler:
             return update_course
         try:
             logging.info(
-                'Call createCourseEdit interface start and course_id:%s' %
+                'Call createCourseEdit interface start and course_id:%s',
                 course_id)
             url = ApiConstant.CREATE_NEW_COURSE_EDIT_URL.format(course_id)
             response = HttpCommonResponse(self._request_sender.post(url=url))
@@ -688,15 +683,15 @@ class CourseHandler:
             logging.info(
                 'Call createCourseEdit interface end and resultCode:%s,:'
                 'error_message%s'
-                % (create_course_result.result.result_desc,
-                   create_course_result.result.result_code))
+                , create_course_result.result.result_desc,
+                   create_course_result.result.result_code)
 
             return update_course
         except EduKitException as e:
             logging.error(
                 'Call createCourseEdit interface failed and course_id:%s, '
                 'error_message:%s, resultCode:%s'
-                % (course_id, e.message, e.code))
+                , course_id, e.message, e.code)
             update_course.result = Helpers.build_error_result(
                 CommonErrorCode.CALL_API_INTERFACE_FAILED)
             return update_course
