@@ -8,3 +8,5 @@ class LessonConstant:
     RESPONSE = 'edukit_sdk.edukit.common.model.response.Response'
     UPDATE_LESSON_RESULT = 'edukit_sdk.edukit.lesson.impl.' \
                            'update_lesson_result.UpdateLessonResult'
+    RESULT = 'result'
+    RESULT_DESC = 'resultDesc'
