@@ -70,17 +70,20 @@ class LessonHandler:
                 LessonConstant.CreateLessonResult)
         except EduKitException as e:
             logging.info(
-                'Call create lesson interface failed. ErrorMessage: %s' %
+                'Call create lesson interface failed. ErrorMessage: %s',
                 e.message)
             response.result = Helpers.build_error_result(
                 CommonErrorCode.CALL_API_INTERFACE_FAILED)
             return response
         return response
 
-    def update_lesson_data(self, course_id, course_edit_id, lesson_id,
-                           lesson_edit_id, lesson: Lesson,
+    def update_lesson_data(self, lesson_edit: LessonEdit, lesson_id,
                            rsp: LessonUpdateResponse):
         # 更新章节元数据
+        course_id = lesson_edit.course_id
+        course_edit_id = lesson_edit.course_edit_id
+        lesson_edit_id = lesson_edit.lesson_edit_id
+        lesson = lesson_edit.lesson
         update_lesson_meta_data_result = self._update_lesson_meta_data(
             course_id, course_edit_id, lesson_id, lesson_edit_id, lesson)
         rsp.update_lesson_meta_data_result = update_lesson_meta_data_result
@@ -92,7 +95,7 @@ class LessonHandler:
                 result_desc = update_lesson_meta_data_result.result.result_desc
                 logging.error(
                     'Update lesson metadata failed and result_code: %s,'
-                    'error_message: %s  ' % (result_code, result_desc))
+                    'error_message: %s  ', result_code, result_desc)
                 rsp.result = Helpers.build_error_result(
                     CommonErrorCode.PARTIAL_SUCCESS)
                 return rsp
@@ -110,9 +113,9 @@ class LessonHandler:
                     CommonConstant.RESULT_SUCCESS:
                 logging.error(
                     'Update lesson localized data failed and result_code: %s,'
-                    'error_message: %s ' %
-                    (update_lesson_localized_data_result.result.result_code,
-                     update_lesson_localized_data_result.result.result_desc))
+                    'error_message: %s ',
+                    update_lesson_localized_data_result.result.result_code,
+                     update_lesson_localized_data_result.result.result_desc)
                 rsp.result = Helpers.build_error_result(
                     CommonErrorCode.PARTIAL_SUCCESS)
                 return rsp
@@ -133,9 +136,14 @@ class LessonHandler:
         rsp.result = Helpers.build_error_result(CommonErrorCode.SUCCESS)
         return rsp
 
-    def update_lesson_data_create(self, course_id, course_edit_id, lesson_id,
-                                  lesson_edit_id, lesson: Lesson,
+    def update_lesson_data_create(self, lesson_edit: LessonEdit, lesson_id,
                                   rsp: LessonCreateResponse):
+
+        course_id = lesson_edit.course_id
+        course_edit_id = lesson_edit.course_edit_id
+        lesson_edit_id = lesson_edit.lesson_edit_id
+        lesson = lesson_edit.lesson
+
         update_lesson_meta_data_result = self._update_lesson_meta_data(
             course_id, course_edit_id, lesson_id, lesson_edit_id, lesson)
         rsp.update_lesson_meta_data_result = update_lesson_meta_data_result
@@ -146,8 +154,8 @@ class LessonHandler:
                 logging.error(
                     'Update lesson metadata failed and result_code: %s,'
                     'error_message: %s  '
-                    % (update_lesson_meta_data_result.result.result_code,
-                       update_lesson_meta_data_result.result.result_desc))
+                    , update_lesson_meta_data_result.result.result_code,
+                       update_lesson_meta_data_result.result.result_desc)
                 rsp.result = Helpers.build_error_result(
                     CommonErrorCode.PARTIAL_SUCCESS)
                 return rsp
@@ -166,8 +174,8 @@ class LessonHandler:
                 logging.error(
                     'Update lesson localized data failed and result_'
                     'code: %s,error_message: %s '
-                    % (update_create_localized_data_result.result.result_code,
-                       update_create_localized_data_result.result.result_desc))
+                    , update_create_localized_data_result.result.result_code,
+                       update_create_localized_data_result.result.result_desc)
                 rsp.result = Helpers.build_error_result(
                     CommonErrorCode.PARTIAL_SUCCESS)
                 return rsp
@@ -184,14 +192,14 @@ class LessonHandler:
             logging.info(
                 'Lesson metadata is empty, courseId = %s, courseEditId = %s, '
                 'lessonId = %s, lessonEditId = %s.'
-                % (course_id, course_edit_id, lesson_id, lesson_edit_id))
+                , course_id, course_edit_id, lesson_id, lesson_edit_id)
 
             return response
         logging.info(
             'Update lesson metadata begin, courseId = %s, courseEditId = %s, '
             'lessonId = %s, lessonEditId = %s, '
-            'lessonName = %s' % (course_id, course_edit_id, lesson_id,
-                                 lesson_edit_id, lesson.meta_data.name))
+            'lessonName = %s', course_id, course_edit_id, lesson_id,
+                                 lesson_edit_id, lesson.meta_data.name)
 
         update_meta_data_request = UpdateMetaDataRequest()
         update_meta_data_request.meta_data = lesson.meta_data
@@ -207,7 +215,7 @@ class LessonHandler:
         except EduKitException as e:
             logging.info(
                 'Call update lesson metadata interface failed. '
-                'ErrorMessage: %s' % e.message)
+                'ErrorMessage: %s', e.message)
             response.result = Helpers.build_error_result(
                 CommonErrorCode.CALL_API_INTERFACE_FAILED)
             return response
@@ -221,14 +229,14 @@ class LessonHandler:
             logging.info(
                 'Lesson multi_lang_localized_data_list is empty, '
                 'courseId = %s, courseEditId = %s, lessonId = %s, '
-                'lessonEditId = %s.' %
-                (course_id, course_edit_id, lesson_id, lesson_edit_id))
+                'lessonEditId = %s.',
+                course_id, course_edit_id, lesson_id, lesson_edit_id)
 
             return response
         logging.info(
             'Update lesson localized data begin, courseId = %s, '
             'courseEditId = %s, lessonId = %s, lessonEditId = %s, '
-            % (course_id, course_edit_id, lesson_id, lesson_edit_id))
+            , course_id, course_edit_id, lesson_id, lesson_edit_id)
         response.result = Helpers.build_error_result(CommonErrorCode.SUCCESS)
         for item in lesson.multi_lang_localized_data_list:
             update_localized_data_request = UpdateLocalizedDataRequest()
@@ -249,9 +257,13 @@ class LessonHandler:
                 update_localized_data_request.localized_media = \
                     update_localized_media_result_list
 
+            lesson_edit = LessonEdit()
+            lesson_edit.course_id = course_id
+            lesson_edit.course_edit_id = course_edit_id
+            lesson_edit.lesson_edit_id = lesson_edit_id
             update_localized_data_rsp = self._update_localized_data(
-                course_id, course_edit_id, lesson_id, lesson_edit_id,
-                update_localized_data_request, item.language)
+                lesson_edit, lesson_id, update_localized_data_request,
+                item.language)
             if update_localized_data_rsp and update_localized_data_rsp.result \
                     and update_localized_data_rsp.result.result_code != \
                     CommonConstant.RESULT_SUCCESS:
@@ -259,11 +271,15 @@ class LessonHandler:
                 break
         return response
 
-    def _update_localized_data(
-            self, course_id, course_edit_id, lesson_id, lesson_edit_id,
-            update_localized_data_request: UpdateLocalizedDataRequest, lang):
+    def _update_localized_data(self, lesson_edit: LessonEdit, lesson_id,
+                               update_localized_data_request:
+                               UpdateLocalizedDataRequest, lang):
         response = Response()
         try:
+            course_id = lesson_edit.course_id
+            course_edit_id = lesson_edit.course_edit_id
+            lesson_edit_id = lesson_edit.lesson_edit_id
+
             url = ApiConstant.LESSON_LOCALIZED_DATA_URL.format(
                 course_id, course_edit_id, lesson_id, lesson_edit_id, lang)
             http_common_response = HttpCommonResponse(
@@ -274,8 +290,7 @@ class LessonHandler:
         except EduKitException as e:
             logging.info(
                 'Call update lesson localized data interface failed. '
-                'ErrorMessage: %s'
-                % e.message)
+                'ErrorMessage: %s', e.message)
             response.result = Helpers.build_error_result(
                 CommonErrorCode.CALL_API_INTERFACE_FAILED)
             return response
@@ -288,7 +303,7 @@ class LessonHandler:
             logging.info(
                 'Delete lesson language begin, courseId = %s, '
                 'courseEditId = %s, lessonId = %s, lessonEditId = %s, '
-                'language = %s' % (course_id, course_edit_id, lesson_id,
+                'language = %s', (course_id, course_edit_id, lesson_id,
                                    lesson_edit_id, language))
             try:
                 url = ApiConstant.LESSON_LOCALIZED_DATA_URL.format(
@@ -305,9 +320,9 @@ class LessonHandler:
                         'courseEditId = %s, '
                         'lessonId = %s, lessonEditId = %s, language = %s, '
                         'result_code: %s,error_message: %s'
-                        % (course_id, course_edit_id, lesson_id,
+                        , course_id, course_edit_id, lesson_id,
                            lesson_edit_id, language, result.result.result_code,
-                           result.result.result_desc))
+                           result.result.result_desc)
                     response.result = result.result
                     return response
             except EduKitException as e:
@@ -316,14 +331,14 @@ class LessonHandler:
                     'courseEditId = %s, '
                     'lessonId = %s, lessonEditId = %s, language = %s, '
                     'errorCode:%s, errormessage:%s'
-                    % (course_id, course_edit_id, lesson_id, lesson_edit_id,
-                       language, e.message, e.code))
+                    , course_id, course_edit_id, lesson_id, lesson_edit_id,
+                       language, e.message, e.code)
                 response.result = Helpers.build_error_result(
                     CommonErrorCode.CALL_API_INTERFACE_FAILED)
                 return response
             logging.info(
                 'Delete lesson language end, courseId = %s, courseEditId = %s,'
-                ' lessonId = %s, lessonEditId = %s, language = %s' %
+                ' lessonId = %s, lessonEditId = %s, language = %s',
                 (course_id, course_edit_id, lesson_id,
                  lesson_edit_id, language))
 
@@ -355,8 +370,7 @@ class LessonHandler:
         except EduKitException as e:
             logging.info(
                 'Call create lesson new edit interface failed. code:%s '
-                'ErrorMessage: %s'
-                % (e.code, e.message))
+                'ErrorMessage: %s', (e.code, e.message))
             response.result = Helpers.build_error_result(
                 CommonErrorCode.CALL_API_INTERFACE_FAILED)
             return response
@@ -365,8 +379,7 @@ class LessonHandler:
     def delete_lesson(self, course_id, course_edit_id, lesson_id):
         logging.info(
             'Delete lesson begin, courseId = %s, courseEditId = %s, '
-            'lessonId = %s'
-            % (course_id, course_edit_id, lesson_id))
+            'lessonId = %s', (course_id, course_edit_id, lesson_id))
         response = Response()
         try:
             url = ApiConstant.LESSON_URL.format(course_id, course_edit_id,
@@ -377,14 +390,14 @@ class LessonHandler:
                                               LessonConstant.RESPONSE)
             if response and response.result and response.result.result_code \
                     != CommonConstant.RESULT_SUCCESS:
-                logging.error(
-                    'Delete lesson failed and result_code: %s,error_message: '
-                    '%s' % (response.result.result_code,
-                            response.result.result_desc))
+                logging.error('Delete lesson failed and '
+                              'result_code: %s,error_message: ''%s',
+                              (response.result.result_code,
+                               response.result.result_desc))
                 return response
         except EduKitException as e:
             logging.info(
-                'Call delete lesson interface failed. ErrorMessage: %s' %
+                'Call delete lesson interface failed. ErrorMessage: %s',
                 e.message)
             response.result(
                 Helpers.build_error_result(
@@ -392,14 +405,14 @@ class LessonHandler:
             return response
         logging.info(
             'Delete lesson end, courseId = %s, courseEditId = %s, '
-            'lessonId = %s' % (course_id, course_edit_id, lesson_id))
+            'lessonId = %s', (course_id, course_edit_id, lesson_id))
         return response
 
     def reset_lesson(self, course_id, course_edit_id, lesson_id):
         logging.info(
             'Reset lesson begin, courseId = %s, courseEditId = %s, '
             'lessonId = %s'
-            % (course_id, course_edit_id, lesson_id))
+            , (course_id, course_edit_id, lesson_id))
         response = Response()
         try:
             url = ApiConstant.LESSON_RESET_URL.format(course_id,
@@ -414,23 +427,19 @@ class LessonHandler:
                 logging.error(
                     'Reset lesson interface failed and result_code: %s,'
                     'error_message: %s'
-                    %
-                    (response.result.result_code, response.result.result_desc))
+                    ,
+                    response.result.result_code, response.result.result_desc)
                 return response
         except EduKitException as e:
             logging.error(
-                'Call reset lesson interface failed. ErrorMessage: %s' %
-                e.message)
+                'Call reset lesson interface failed. '
+                'ErrorMessage: %s', e.message)
             response.result = Helpers.build_error_result(
                 CommonErrorCode.CALL_API_INTERFACE_FAILED)
             return response
         logging.info(
             'Reset lesson end, courseId = %s, courseEditId = %s, lessonId = %s'
-            % (
-                course_id,
-                course_edit_id,
-                lesson_id,
-            ))
+            , (course_id, course_edit_id, lesson_id))
         return response
 
     def _upload_localized_data(
@@ -460,12 +469,12 @@ class LessonHandler:
                 request_sender=self._request_sender)
             result = file_upload.upload()
         except EduKitException as e:
-            logging.error('Upload cover image failed. errMsg:%s' %
+            logging.error('Upload cover image failed. errMsg:%s',
                           e.message)
             return False
 
         if not Helpers.is_success(result):
-            logging.error('Upload cover image failed. errMsg:%s' %
+            logging.error('Upload cover image failed. errMsg:%s',
                           result.get(LessonConstant.RESULT).get(
                               LessonConstant.RESULT_DESC))
             return False
